# Release 0.8.33

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The Workbench framework continues to flex to support different real world use cases when operating a set of production machine learning pipelines.

**Note:** These release notes cover the changes from `0.8.29` to `0.8.33`


### General
**Replaced WatchTower Code:** Had **lots** of issues with WatchTower on Glue/Lambda, the use of forks/threads was overkill for our logging needs, so simply replaced the code with boto3 `put_log_events()` calls and some simple token handling and buffering.

### API Changes
None
	
### Improvements/Fixes
**DataSource from DataFrame:**
When creating a DataSource from a Pandas Dataframe, the internal `transform()` was not deleting the existing DataSource (if it existed).

**ROCAUC on subset of classes:** When running inference on input data that only had a subset of the classification labels (e.g. rows only had "low" and "medium" when model was trained on "low", "medium", "high"). The input to ROCAUC needed to be adjusted so that ROCAUC doesn't crash. When this case happens we're returning proper defaults based on scikit learn docs.

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


